function [A,drive,extinct]=appendix(proportionA,proportionXs,h,p,d,r,m,c,N0,heterobehaviour,egg_goal)

% values with examples, and what they mean
% proportionA=0.3; initial proportion of A
% proportionXs=0.1; initial proportion of drive-X
% h=0.1; extra fecundity cost paid by X*X* females
% p=0.1; cost of mating multiply; females have fecundity 1-p if they have two mates
% d=0.5; % X*Y males transmit an X* chromosome with probability (1+d)/2 and a Y with probability (1-d)/2
% r=1; % sperm replenishment rate (funny enough it's modelled as a 'depletion of the depletedness' as maths turns out easier that way)
% NOTE THAT IN FUTURE r COULD BE 1x2 FOR DIFFERENT MALE TYPES - BUT NOT YET IMPLEMENTED
% m=10; % mating rate
% c=0.2; % sperm competitive success of drive males
% N0=1000; % individuals of one sex in generation 0
% heterobehaviour: if this is 0 then Aa heterozygotes behave like aa, if 1 then they behave like AA
% egg_goal=100; % in thousands: how many eggs must be produced, before the program stops. If egg_goal is 100 then 100000 eggs will be produced

% outputs are: A's first column = number of a alleles in each egg-thousand; A's 2nd column = number of A alleles
% drive's first column = number of X alleles in each egg-thousand; second column = number of X* alleles

% Although some females want to mate twice and others want to mate once,
% they actually get a number of matings that depends on the number/frequency of males
% in the pop. This is done with a time window of length 1. If a polyandrous female
% doesn't find another male during that, she simply uses the sperm of the 1st male
% only. Females pay the

% Female fecundity also depends on the sperm depletedness state of males. Fecundity is proportional to (1-depletedness)^5 for singly mated
% and to min(1,(1-depletedness1^5)+(1-depletedness2^5)) for doubly mated females.

% males are described as:
% column 1: paternally inherited a (0) or A (1)
% column 2: maternally inherited a (0) or A (1)
% column 3: X or X* (X = 0, X* = 1). Note the other sex chromosome must be
%   a Y as these are males, thus no column needed for that.
% column 4: sperm deplenishment, is 0 when mature, rises to 1 when mated
% and starts declining as exp(-rt) where r is replenishment rate
% column 5: time of maturation. Male dies 1 unit time after maturation

% females are described as:
% column 1: paternally inherited a (0) or A (1)
% column 2: maternally inherited a (0) or A (1)
% column 3: paternally inherited X or X* (X = 0, X* = 1)
% column 4: maternally inherited X or X* (X = 0, X* = 1)
% columns 5-8: mate 1's alleles & sperm status (in the same order as columns 1-4 in males), for virgins these are NaN
% columns 9-12: mate 2's alleles & sperm status (in the same order as columns 1-4 in males), for virgins these are NaN
% column 13: time of first mating (NaN if a virgin). Eggs laid 1 unit time after this, and female dies

% Eggs are described by genotype and time of laying
% column 1: paternally inherited a (0) or A (1)
% column 2: maternally inherited a (0) or A (1)
% column 3: paternally inherited X, X* or Y (X = 0, X* = 1, Y = -1)
% column 4: maternally inherited X or X* (X = 0, X* = 1)
% column 5: time of laying

% create males
Males=[rand([N0 1])<proportionA, rand([N0 1])<proportionA, rand([N0 1])<proportionXs, zeros([N0 2])];
Females=[rand([N0 1])<proportionA, rand([N0 1])<proportionA, rand([N0 1])<proportionXs, rand([N0 1])<proportionXs, NaN*ones([N0 9])];
Eggs=[];
finaleggs=[];
A=zeros([egg_goal 2]);
drive=zeros([egg_goal 2]);

realtime=0; eggsproduced=0; extinct=0;

while eggsproduced<egg_goal*1000
    
    nF=size(Females,1); nM=size(Males,1);
    
    % a mating occurs for any female?
    % default is: female doesn't want to mate
    times(1)=Inf;
    t2mating=Inf*ones([nF 1]);
    % then reverse that decision, to say that a female actually wants to mate if she (a) hasn't mated
    % at all yet, or (b) has only mated once and has (b1) at least one A
    % allele or (b2) two A alleles
    if ~isempty(t2mating)
        if heterobehaviour==0 % once-mated Aa heterozygotes behave like aa i.e. they don't mate again
            f=[find(isnan(Females(:,5)));
                find((mean(Females(:,1:2)'))'>0.5 & ~isnan(Females(:,5)) & isnan(Females(:,9)))];
        else % once-mated Aa heterozygotes behave like AA i.e. they do mate again
            f=[find(isnan(Females(:,5)));
                find((mean(Females(:,1:2)'))'>=0.5 & ~isnan(Females(:,5)) & isnan(Females(:,9)))];
        end
        realmatetimes=exprnd(1./(m*nM),length(f),1);
        t2mating(f)=realmatetimes;
        times(1)=min(t2mating);
    end
    
    % a male dies?
    t2maledeath=exprnd(1,nM,1);
    if ~isempty(t2maledeath) times(2)=min(t2maledeath); else times(2)=Inf; end;
    
    % a female dies?
    t2femaledeath=exprnd(1,nF,1);
    if ~isempty(t2femaledeath) times(3)=min(t2femaledeath); else times(3)=Inf; end;
    
    % a female lays eggs?
    t2femalelays=(Females(:,13)+1)-realtime; t2femalelays(isnan(Females(:,13)))=Inf;
    if ~isempty(t2femalelays) times(4)=min(t2femalelays); else times(4)=Inf; end;
    
    nE=size(Eggs,1);
    if nE>0
        % Eggs/larvae die? this one is density dependent
        t2eggdies=exprnd(10000./(nE^3)); % note - this is not per egg, but one number
        
        % Eggs/larvae mature?
        t2eggmatures=Eggs(:,5)+0.05-realtime; % here we are assuming egg->adult maturation time is 0.05x adult lifespan Could be changed...
    else
        t2eggdies=Inf;
        t2eggmatures=Inf;
    end
    times(5)=min(t2eggdies); times(6)=min(t2eggmatures);
    
    % which event comes first?
    [tmp,whichone]=min(times);
    
    if all(isinf(times)) Afreq=NaN; driveprop=NaN; extinct=1; break;
    else
        switch whichone
            
            case 1, % there is a mating
                
                %disp('a mating!')
                [deltat,mom]=min(t2mating);
                dad=unidrnd(nM);
                Males(:,4)=Males(:,4)*exp(-r*deltat); % update all males' depletedness
                if isnan(Females(mom,5)) % this is the female's first mating
                    Females(mom,5:8)=Males(dad,1:4); % alleles of her first mate
                    Females(mom,13)=realtime; % store time of her first mating
                else % this is her 2nd mate
                    Females(mom,9:12)=Males(dad,1:4); % alleles of her 2nd mate
                end; 
                Males(dad,4)=1; % this male now has maximal depletedness (note this means that higher sperm depletion = less sperm available)
                
            case 2,% a male dies
                %disp('a male dies!')
                [deltat,deadmale]=min(t2maledeath);
                Males(:,4)=Males(:,4)*exp(-r*deltat); % update all males' depletedness
                Males(deadmale,:)=[];
                
            case 3, % a female dies
                %disp('a female dies!')
                [deltat,deadfemale]=min(t2femaledeath);
                Males(:,4)=Males(:,4)*exp(-r*deltat); % update all males' depletedness
                Females(deadfemale,:)=[];
                
            case 4, % a female lays eggs
                
                % let's figure out which egg-thousand our timekeeping is in
                t=ceil((eggsproduced+1)/1000);
                %disp('a female reproduces');
                [deltat,mom]=min(t2femalelays);
                eggs=[]; % these are the new eggs by this female
                Males(:,4)=Males(:,4)*exp(-r*deltat); % update all males' depletedness
                
                if ~isnan(Females(mom,9)) % female has mated twice
                    
                    % REPRODUCTION WITH TWO MALES
                    % female fecundity: as with one male below, but now the total sperm from both males counts.
                    % fecundity is near intact (near 1) if depletion is 0 to relatively severe, but falls if depletion is near 1, thus we use function min(1,sum(1-depletion^5)) where the sum is taken over both males sperm.
                    % 'mendel' below is always a temporary variable that tells from which parental column the offspring will pick its genes
                    
                    if sum(Females(mom,3:4))==2 % female is X*X*
                        n=poissrnd(10*(1-h)*(1-p)*min(1,(1-Females(mom,8)^5)+(1-Females(mom,12)^5)));
                    else n=poissrnd(10*(1-p)*min(1,(1-Females(mom,8)^5)+(1-Females(mom,12)^5)));
                    end;
                    
                    if n>0
                        
                        % then the relative competitive success of each male for each egg, and the consequent per-egg probability that male 2 is the sire
                        compsucc1=(1-Females(mom,8)); compsucc2=(1-Females(mom,12));
                        if sum(Females(mom,[7 11]))==1 % only one of the males has the X* and this male will have to be made disadvantaged
                            if Females(mom,7)==1 compsucc1=c*compsucc1;
                            else compsucc2=c*compsucc2;
                            end
                        end
                        male2sires=rand([n 1])<compsucc2/(compsucc1+compsucc2);
                        
                        % now actually create the new eggs. All these '4+4' and other clever structures below make
                        % use of the fact that info on different mates is stored in different columns of the female (4 columns per mate)
                        mendel=(4+4*male2sires)+unidrnd(2,n,1); eggs=Females(mom,mendel)'; % a/A from females siring mate
                        mendel=unidrnd(2,n,1); eggs(:,2)=Females(mom,mendel); % a/A from female herself
                        
                        eggs(:,3)=Females(mom,7+4*male2sires); % technicality: initially the code behaves as if the X or X* was always inherited, it then corrects for the chance that itll actually be Y
                        f=find(Females(mom,7+4*male2sires)==0); % fair meiosis happens for these Eggs
                        mendelfair=unidrnd(2,n,1); % if this is 2, we let the Y be inherited, see below
                        mendelunfair=1+(rand([n 1])<(1-d)/2); % if this is 2, we let the Y be inherited, but now Y only gets there with probability (1-d)/2
                        mendel=mendelunfair; mendel(f)=mendelfair(f);
                        eggs(mendel==2,3)=-1; % sex chromosome from dad turns out to be Y for these cases CHECK THIS LINE
                        
                        mendel=2+unidrnd(2,n,1); eggs(:,4)=Females(mom,mendel); % inherit one of mom's sex chromosomes
                        eggs(:,5)=realtime;
                        Eggs=[Eggs; eggs];
                        eggsproduced=eggsproduced+size(eggs,1);
                        % now how do these alleles count towards what's going on in the population right now
                        polyandryalleles=eggs(:,1:2); 
                        A(t,:)=A(t,:)+[sum(polyandryalleles(:)==0) sum(polyandryalleles(:)==1)];
                        sexchromalleles=eggs(:,3:4);
                        drive(t,:)=drive(t,:)+[sum(sexchromalleles(:)==0) sum(sexchromalleles(:)==1)];
                    end
                    
                elseif ~isnan(Females(mom,5)) % female has mated once
                    
                    % REPRODUCTION WITH ONE MALE
                    % create n Eggs, where n depends on sperm status of the females mate and also on h if female is X*X*
                    % fecundity is near intact (near 1) if depletion is 0 to relatively severe, but falls if depletion is near 1, thus we use function (1-depletion)^5 where depletion=Females(mom,8)
                    
                    if sum(Females(mom,3:4))==2
                        n=poissrnd(10*(1-h)*(1-Females(mom,8)^5));
                    else
                        n=poissrnd(10*(1-Females(mom,8)^5));
                    end;
                    
                    if n>0
                        
                        mendel=4+unidrnd(2,n,1); eggs(:,1)=Females(mom,mendel); % a/A from females first mate
                        mendel=unidrnd(2,n,1); eggs(:,2)=Females(mom,mendel); % a/A from female herself
                        eggs(:,3)=Females(mom,7);
                        if Females(mom,7)==0 % fair meiosis
                            mendel=unidrnd(2,n,1); % if this is 2, we let the Y be inherited, see below
                        else % unfair meiosis: Y only gets there with probability (1-d)/2
                            mendel=1+(rand([n 1])<(1-d)/2);
                        end
                        eggs(mendel==2,3)=-1; % sex chromosome from dad turns out to be Y for these cases
                        mendel=2+unidrnd(2,n,1); eggs(:,4)=Females(mom,mendel); % inherit one of mom's sex chromosomes
                        eggs(:,5)=realtime; % store the time when egg was produced
                        Eggs=[Eggs; eggs];
                        eggsproduced=eggsproduced+size(eggs,1);
                        % now how do these alleles count towards what's going on in the population right now
                        polyandryalleles=eggs(:,1:2); 
                        A(t,:)=A(t,:)+[sum(polyandryalleles(:)==0) sum(polyandryalleles(:)==1)];
                        sexchromalleles=eggs(:,3:4);
                        drive(t,:)=drive(t,:)+[sum(sexchromalleles(:)==0) sum(sexchromalleles(:)==1)];
                    end
                end
                Females(mom,:)=[]; % mom is now de facto dead (= has reproduced and won't mate again)
                
            case 5, % an egg dies
                
                %disp('An egg dies!')
                deltat=t2eggdies;
                Males(:,4)=Males(:,4)*exp(-r*deltat); % update all males' depletedness
                whodies=unidrnd(size(Eggs,1)); Eggs(whodies,:)=[];
                
            case 6, % an egg matures
                %disp('An egg matures!')
                [deltat,whichegg]=min(t2eggmatures);
                Males(:,4)=Males(:,4)*exp(-r*deltat); % update all males' depletedness
                if Eggs(whichegg,3)==-1 % this one will be a male
                    Males=[Males; Eggs(whichegg,[1:2 4]) 0 realtime+deltat];
                else % this one will be a female
                    Females=[Females; Eggs(whichegg,1:4) NaN*ones([1 9])];
                end
                Eggs(whichegg,:)=[];
                
        end
        realtime=realtime+deltat;
    end
end